@@ -1,4 +1,5 @@
 var EXPORTED_SYMBOLS = ["stepBrowser"];
+Components.utils.import("resource://indexdata/runtime/core.js");
 Components.utils.import("resource://indexdata/ui/app.js");
 Components.utils.import("resource://indexdata/util/logging.js");
 Components.utils.import("resource://indexdata/util/xmlHelper.js");
@@ -117,10 +118,7 @@ var stepBrowser = {
   },
   toggleSticky: function () {
     app.stickyNewStep = !app.stickyNewStep;
-    let prefs = Components.classes["@mozilla.org/preferences-service;1"]
-      .getService(Components.interfaces.nsIPrefService)
-      .getBranch("indexdata.cf.");
-    prefs.setBoolPref("stickyNewStep", app.stickyNewStep);
+    core.idprefs.setBoolPref("stickyNewStep", app.stickyNewStep);
   },
   createStep: function (stepName) {
     (function () { taskPane.stepTree.newStep(stepName) })();
