@@ -35,6 +35,15 @@ xulHelper = {
     }
   },
 
+  // Separator - a line across the surface
+  // style can be one of: groove, groove-thin, thin
+  separator: function(parentnode, style) {
+    if ( ! style )
+      style = "groove";
+    var attributes = { class: style };
+    var sep = xmlHelper.appendNode(parentnode,"separator", null, attributes);
+  },
+  
   // Simple helpers to produce input elements for the step-editing screens
   captionField: function(parentnode, caption, attributes) {
     //var capt = xmlHelper.appendNode(parentnode, "caption", caption, attributes);
@@ -195,7 +204,7 @@ xulHelper = {
       }
       logger.debug("prependHistory: before: h.length=" + step.conf[histindex].length + "\n");
       var i;
-      for ( i=0; (i<step.conf[histindex].length) && (newhist.length<10); i++) {
+      for ( let i=0; (i<step.conf[histindex].length) && (newhist.length<10); i++) {
         if (step.conf[histindex][i] != step.conf[confindex] ) {
           logger.debug("_prependHistory: adding '" + step.conf[histindex][i] + "' \n");
           newhist.push(step.conf[histindex][i]);
@@ -205,7 +214,7 @@ xulHelper = {
       logger.debug("prependHistory: after: h.length=" + step.conf[histindex].length + "\n");
       logger.debug("prependHistory: menupop= " + menupop + "\n");
       xmlHelper.emptyChildren(menupop);
-      for ( i=0; i<step.conf[histindex].length; i++) {
+      for ( let i=0; i<step.conf[histindex].length; i++) {
         var val = step.conf[histindex][i];
         xmlHelper.appendNode(menupop, "menuitem", null,
           { label: val, value: val, selected: (i==0) });
@@ -252,7 +261,7 @@ xulHelper = {
     if (Array.isArray(options)) {
       if (extraoptions && extraoptions.length) {
         var dedupped = [];
-        for (i = 0; i < extraoptions.length; i++) {
+        for (let i = 0; i < extraoptions.length; i++) {
           var val = extraoptions[i];
           if (val !== "" && options.indexOf(val) < 0) {
             dedupped.push(val);
@@ -261,7 +270,7 @@ xulHelper = {
         options = dedupped.concat(options);
       }
 
-      for (i = 0; i < options.length; i++) {
+      for (let i = 0; i < options.length; i++) {
         let item = options[i];
         let key = '';
         let value = '';
