@@ -3,8 +3,7 @@
 
 #include "cf_logger.h"
 
-#include "prtypes.h"
-typedef PRUint32 nsresult;
+#include "nscore.h"
 
 /**
  * Initializes embedding, i.e. loads needed libs do other needed setup.
