@@ -355,7 +355,7 @@ nsresult MozView::CreateBrowser(void* aParentWindow, PRInt32 x, PRInt32 y,
     }
 #endif
 
-    return 0;
+    return NS_OK;
 }
 
 CF_Logger *MozView::GetLogger()
@@ -379,7 +379,11 @@ nsresult MozView::GetMessages()
 	PRUint32 count;
         WRBUF w = wrbuf_alloc();
 
+#if MOZ_MAJOR >= 19
+	consoleService->GetMessageArray(&count, &messages);
+#else
 	consoleService->GetMessageArray(&messages, &count);
+#endif
 	for (PRUint32 i = 0; i < count; i++)
 	{
 	    nsString msg;
@@ -399,7 +403,7 @@ nsresult MozView::GetMessages()
 	consoleService->Reset();
         wrbuf_destroy(w);
     }
-    return 0;
+    return NS_OK;
 }
 
 nsresult MozView::SetPositionAndSize(PRInt32 x, PRInt32 y, PRInt32 width, PRInt32 height)
@@ -408,10 +412,7 @@ nsresult MozView::SetPositionAndSize(PRInt32 x, PRInt32 y, PRInt32 width, PRInt3
     nsCOMPtr<nsIBaseWindow> baseWindow;
     baseWindow = do_QueryInterface(mPrivate->webBrowser);
     rv = baseWindow->SetPositionAndSize(x, y, width, height, PR_TRUE);
-    if (NS_FAILED(rv))
-	return 1;
-    else
-	return 0;
+    return rv;
 }
 
 nsresult MozView::LoadURI(const char* uri)
